@@ -1,4 +1,5 @@
-# -*- coding: utf-8 -*-
+# Copyright (C) 2020 Red Hat, Inc.
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -31,8 +32,8 @@ openstackdocs_bug_tag = ''
 master_doc = 'index'
 
 # General information about the project.
-project = u'oslo.i18n'
-copyright = u'2014, OpenStack Foundation'
+project = 'oslo.i18n'
+copyright = '2014, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
